Basis sets
==========

.. automodule:: mumott.methods.basis_sets

.. index::
   single: Class reference; SphericalHarmonics
.. autoclass:: mumott.methods.basis_sets.SphericalHarmonics
   :members:
   :undoc-members:
   :inherited-members:


